/*******************************************************************************
* File Name: PWM_C.c
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the PWM_C
*  component.
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PWM_C.h"

/** Indicates whether or not the PWM_C has been initialized. 
*  The variable is initialized to 0 and set to 1 the first time 
*  PWM_C_Start() is called. This allows the Component to 
*  restart without reinitialization after the first call to 
*  the PWM_C_Start() routine.
*/
uint8_t PWM_C_initVar = 0U;

/** The instance-specific configuration structure. This should be used in the 
*  associated PWM_C_Init() function.
*/ 
cy_stc_tcpwm_pwm_config_t const PWM_C_config =
{
    .pwmMode = 5UL,
    .clockPrescaler = 0UL,
    .pwmAlignment = 2UL,
    .deadTimeClocks = 38UL,
    .runMode = 0UL,
    .period0 = 2399UL,
    .period1 = 32768UL,
    .enablePeriodSwap = false,
    .compare0 = 2399UL,
    .compare1 = 2399UL,
    .enableCompareSwap = true,
    .interruptSources = 1UL,
    .invertPWMOut = 0UL,
    .invertPWMOutN = 0UL,
    .killMode = 0UL,
    .swapInputMode = 0UL,
    .swapInput = CY_TCPWM_INPUT_CREATOR,
    .reloadInputMode = 3UL,
    .reloadInput = CY_TCPWM_INPUT_CREATOR,
    .startInputMode = 3UL,
    .startInput = CY_TCPWM_INPUT_CREATOR,
    .killInputMode = 3UL,
    .killInput = CY_TCPWM_INPUT_CREATOR,
    .countInputMode = 3UL,
    .countInput = CY_TCPWM_INPUT_CREATOR,
};


/*******************************************************************************
* Function Name: PWM_C_Start
****************************************************************************//**
*
*  Calls the PWM_C_Init() when called the first time and enables 
*  the PWM_C. For subsequent calls the configuration is left 
*  unchanged and the component is just enabled.
*
* \globalvars
*  \ref PWM_C_initVar
*
*******************************************************************************/
void PWM_C_Start(void)
{
    if (0U == PWM_C_initVar)
    {
        (void) Cy_TCPWM_PWM_Init(PWM_C_HW, PWM_C_CNT_NUM, &PWM_C_config);

        PWM_C_initVar = 1U;
    }

    Cy_TCPWM_Enable_Multiple(PWM_C_HW, PWM_C_CNT_MASK);
    
    #if (PWM_C_INPUT_DISABLED == 7UL)
        Cy_TCPWM_TriggerStart(PWM_C_HW, PWM_C_CNT_MASK);
    #endif /* (PWM_C_INPUT_DISABLED == 7UL) */    
}


/* [] END OF FILE */
