/***************************************************************************//**
* \file UART_BCP.h
* \version 2.0
*
*  This file provides constants and parameter values for the UART component.
*
********************************************************************************
* \copyright
* Copyright 2016-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(UART_BCP_CY_SCB_UART_PDL_H)
#define UART_BCP_CY_SCB_UART_PDL_H

#include "cyfitter.h"
#include "scb/cy_scb_uart.h"

#if defined(__cplusplus)
extern "C" {
#endif

/***************************************
*   Initial Parameter Constants
****************************************/

#define UART_BCP_DIRECTION  (3U)
#define UART_BCP_ENABLE_RTS (0U)
#define UART_BCP_ENABLE_CTS (0U)

/* UART direction enum */
#define UART_BCP_RX    (0x1U)
#define UART_BCP_TX    (0x2U)

#define UART_BCP_ENABLE_RX  (0UL != (UART_BCP_DIRECTION & UART_BCP_RX))
#define UART_BCP_ENABLE_TX  (0UL != (UART_BCP_DIRECTION & UART_BCP_TX))


/***************************************
*        Function Prototypes
***************************************/
/**
* \addtogroup group_general
* @{
*/
/* Component specific functions. */
void UART_BCP_Start(void);

/* Basic functions */
__STATIC_INLINE cy_en_scb_uart_status_t UART_BCP_Init(cy_stc_scb_uart_config_t const *config);
__STATIC_INLINE void UART_BCP_DeInit(void);
__STATIC_INLINE void UART_BCP_Enable(void);
__STATIC_INLINE void UART_BCP_Disable(void);

/* Register callback. */
__STATIC_INLINE void UART_BCP_RegisterCallback(cy_cb_scb_uart_handle_events_t callback);

/* Configuration change. */
#if (UART_BCP_ENABLE_CTS)
__STATIC_INLINE void UART_BCP_EnableCts(void);
__STATIC_INLINE void UART_BCP_DisableCts(void);
#endif /* (UART_BCP_ENABLE_CTS) */

#if (UART_BCP_ENABLE_RTS)
__STATIC_INLINE void     UART_BCP_SetRtsFifoLevel(uint32_t level);
__STATIC_INLINE uint32_t UART_BCP_GetRtsFifoLevel(void);
#endif /* (UART_BCP_ENABLE_RTS) */

__STATIC_INLINE void UART_BCP_EnableSkipStart(void);
__STATIC_INLINE void UART_BCP_DisableSkipStart(void);

#if (UART_BCP_ENABLE_RX)
/* Low level: Receive direction. */
__STATIC_INLINE uint32_t UART_BCP_Get(void);
__STATIC_INLINE uint32_t UART_BCP_GetArray(void *buffer, uint32_t size);
__STATIC_INLINE void     UART_BCP_GetArrayBlocking(void *buffer, uint32_t size);
__STATIC_INLINE uint32_t UART_BCP_GetRxFifoStatus(void);
__STATIC_INLINE void     UART_BCP_ClearRxFifoStatus(uint32_t clearMask);
__STATIC_INLINE uint32_t UART_BCP_GetNumInRxFifo(void);
__STATIC_INLINE void     UART_BCP_ClearRxFifo(void);
#endif /* (UART_BCP_ENABLE_RX) */

#if (UART_BCP_ENABLE_TX)
/* Low level: Transmit direction. */
__STATIC_INLINE uint32_t UART_BCP_Put(uint32_t data);
__STATIC_INLINE uint32_t UART_BCP_PutArray(void *buffer, uint32_t size);
__STATIC_INLINE void     UART_BCP_PutArrayBlocking(void *buffer, uint32_t size);
__STATIC_INLINE void     UART_BCP_PutString(char_t const string[]);
__STATIC_INLINE void     UART_BCP_SendBreakBlocking(uint32_t breakWidth);
__STATIC_INLINE uint32_t UART_BCP_GetTxFifoStatus(void);
__STATIC_INLINE void     UART_BCP_ClearTxFifoStatus(uint32_t clearMask);
__STATIC_INLINE uint32_t UART_BCP_GetNumInTxFifo(void);
__STATIC_INLINE bool     UART_BCP_IsTxComplete(void);
__STATIC_INLINE void     UART_BCP_ClearTxFifo(void);
#endif /* (UART_BCP_ENABLE_TX) */

#if (UART_BCP_ENABLE_RX)
/* High level: Ring buffer functions. */
__STATIC_INLINE void     UART_BCP_StartRingBuffer(void *buffer, uint32_t size);
__STATIC_INLINE void     UART_BCP_StopRingBuffer(void);
__STATIC_INLINE void     UART_BCP_ClearRingBuffer(void);
__STATIC_INLINE uint32_t UART_BCP_GetNumInRingBuffer(void);

/* High level: Receive direction functions. */
__STATIC_INLINE cy_en_scb_uart_status_t UART_BCP_Receive(void *buffer, uint32_t size);
__STATIC_INLINE void     UART_BCP_AbortReceive(void);
__STATIC_INLINE uint32_t UART_BCP_GetReceiveStatus(void);
__STATIC_INLINE uint32_t UART_BCP_GetNumReceived(void);
#endif /* (UART_BCP_ENABLE_RX) */

#if (UART_BCP_ENABLE_TX)
/* High level: Transmit direction functions. */
__STATIC_INLINE cy_en_scb_uart_status_t UART_BCP_Transmit(void *buffer, uint32_t size);
__STATIC_INLINE void     UART_BCP_AbortTransmit(void);
__STATIC_INLINE uint32_t UART_BCP_GetTransmitStatus(void);
__STATIC_INLINE uint32_t UART_BCP_GetNumLeftToTransmit(void);
#endif /* (UART_BCP_ENABLE_TX) */

/* Interrupt handler */
__STATIC_INLINE void UART_BCP_Interrupt(void);
/** @} group_general */


/***************************************
*    Variables with External Linkage
***************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint8_t UART_BCP_initVar;
extern cy_stc_scb_uart_config_t const UART_BCP_config;
extern cy_stc_scb_uart_context_t UART_BCP_context;
/** @} group_globals */


/***************************************
*         Preprocessor Macros
***************************************/
/**
* \addtogroup group_macros
* @{
*/
/** The pointer to the base address of the hardware */
#define UART_BCP_HW     ((CySCB_Type *) UART_BCP_SCB__HW)
/** @} group_macros */


/***************************************
*    In-line Function Implementation
***************************************/

/*******************************************************************************
* Function Name: UART_BCP_Init
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Init() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_scb_uart_status_t UART_BCP_Init(cy_stc_scb_uart_config_t const *config)
{
   return Cy_SCB_UART_Init(UART_BCP_HW, config, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_DeInit
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_DeInit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_DeInit(void)
{
    Cy_SCB_UART_DeInit(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_Enable
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Enable() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_Enable(void)
{
    Cy_SCB_UART_Enable(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_Disable
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Disable() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_Disable(void)
{
    Cy_SCB_UART_Disable(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_RegisterCallback
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_RegisterCallback() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_RegisterCallback(cy_cb_scb_uart_handle_events_t callback)
{
    Cy_SCB_UART_RegisterCallback(UART_BCP_HW, callback, &UART_BCP_context);
}


#if (UART_BCP_ENABLE_CTS)
/*******************************************************************************
* Function Name: UART_BCP_EnableCts
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_EnableCts() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_EnableCts(void)
{
    Cy_SCB_UART_EnableCts(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: Cy_SCB_UART_DisableCts
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_DisableCts() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_DisableCts(void)
{
    Cy_SCB_UART_DisableCts(UART_BCP_HW);
}
#endif /* (UART_BCP_ENABLE_CTS) */


#if (UART_BCP_ENABLE_RTS)
/*******************************************************************************
* Function Name: UART_BCP_SetRtsFifoLevel
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_SetRtsFifoLevel() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_SetRtsFifoLevel(uint32_t level)
{
    Cy_SCB_UART_SetRtsFifoLevel(UART_BCP_HW, level);
}


/*******************************************************************************
* Function Name: UART_BCP_GetRtsFifoLevel
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetRtsFifoLevel() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetRtsFifoLevel(void)
{
    return Cy_SCB_UART_GetRtsFifoLevel(UART_BCP_HW);
}
#endif /* (UART_BCP_ENABLE_RTS) */


/*******************************************************************************
* Function Name: UART_BCP_EnableSkipStart
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_EnableSkipStart() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_EnableSkipStart(void)
{
    Cy_SCB_UART_EnableSkipStart(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_DisableSkipStart
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_DisableSkipStart() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_DisableSkipStart(void)
{
    Cy_SCB_UART_DisableSkipStart(UART_BCP_HW);
}


#if (UART_BCP_ENABLE_RX)
/*******************************************************************************
* Function Name: UART_BCP_Get
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Get() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_Get(void)
{
    return Cy_SCB_UART_Get(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_GetArray
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetArray() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetArray(void *buffer, uint32_t size)
{
    return Cy_SCB_UART_GetArray(UART_BCP_HW, buffer, size);
}


/*******************************************************************************
* Function Name: UART_BCP_GetArrayBlocking
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetArrayBlocking() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_GetArrayBlocking(void *buffer, uint32_t size)
{
    Cy_SCB_UART_GetArrayBlocking(UART_BCP_HW, buffer, size);
}


/*******************************************************************************
* Function Name: UART_BCP_GetRxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetRxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetRxFifoStatus(void)
{
    return Cy_SCB_UART_GetRxFifoStatus(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_ClearRxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_ClearRxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_ClearRxFifoStatus(uint32_t clearMask)
{
    Cy_SCB_UART_ClearRxFifoStatus(UART_BCP_HW, clearMask);
}


/*******************************************************************************
* Function Name: UART_BCP_GetNumInRxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetNumInRxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetNumInRxFifo(void)
{
    return Cy_SCB_UART_GetNumInRxFifo(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_ClearRxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_ClearRxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_ClearRxFifo(void)
{
    Cy_SCB_UART_ClearRxFifo(UART_BCP_HW);
}
#endif /* (UART_BCP_ENABLE_RX) */


#if (UART_BCP_ENABLE_TX)
/*******************************************************************************
* Function Name: UART_BCP_Put
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Put() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_Put(uint32_t data)
{
    return Cy_SCB_UART_Put(UART_BCP_HW,data);
}


/*******************************************************************************
* Function Name: UART_BCP_PutArray
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_PutArray() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_PutArray(void *buffer, uint32_t size)
{
    return Cy_SCB_UART_PutArray(UART_BCP_HW, buffer, size);
}


/*******************************************************************************
* Function Name: UART_BCP_PutArrayBlocking
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_PutArrayBlocking() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_PutArrayBlocking(void *buffer, uint32_t size)
{
    Cy_SCB_UART_PutArrayBlocking(UART_BCP_HW, buffer, size);
}


/*******************************************************************************
* Function Name: UART_BCP_PutString
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_PutString() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_PutString(char_t const string[])
{
    Cy_SCB_UART_PutString(UART_BCP_HW, string);
}


/*******************************************************************************
* Function Name: UART_BCP_SendBreakBlocking
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_SendBreakBlocking() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_SendBreakBlocking(uint32_t breakWidth)
{
    Cy_SCB_UART_SendBreakBlocking(UART_BCP_HW, breakWidth);
}


/*******************************************************************************
* Function Name: UART_BCP_GetTxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetTxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetTxFifoStatus(void)
{
    return Cy_SCB_UART_GetTxFifoStatus(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_ClearTxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_ClearTxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_ClearTxFifoStatus(uint32_t clearMask)
{
    Cy_SCB_UART_ClearTxFifoStatus(UART_BCP_HW, clearMask);
}


/*******************************************************************************
* Function Name: UART_BCP_GetNumInTxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetNumInTxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetNumInTxFifo(void)
{
    return Cy_SCB_UART_GetNumInTxFifo(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_IsTxComplete
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_IsTxComplete() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE bool UART_BCP_IsTxComplete(void)
{
    return Cy_SCB_UART_IsTxComplete(UART_BCP_HW);
}


/*******************************************************************************
* Function Name: UART_BCP_ClearTxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_ClearTxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_ClearTxFifo(void)
{
    Cy_SCB_UART_ClearTxFifo(UART_BCP_HW);
}
#endif /* (UART_BCP_ENABLE_TX) */


#if (UART_BCP_ENABLE_RX)
/*******************************************************************************
* Function Name: UART_BCP_StartRingBuffer
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_StartRingBuffer() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_StartRingBuffer(void *buffer, uint32_t size)
{
    Cy_SCB_UART_StartRingBuffer(UART_BCP_HW, buffer, size, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_StopRingBuffer
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_StopRingBuffer() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_StopRingBuffer(void)
{
    Cy_SCB_UART_StopRingBuffer(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_ClearRingBuffer
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_ClearRingBuffer() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_ClearRingBuffer(void)
{
    Cy_SCB_UART_ClearRingBuffer(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_GetNumInRingBuffer
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetNumInRingBuffer() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetNumInRingBuffer(void)
{
    return Cy_SCB_UART_GetNumInRingBuffer(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_Receive
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Receive() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_scb_uart_status_t UART_BCP_Receive(void *buffer, uint32_t size)
{
    return Cy_SCB_UART_Receive(UART_BCP_HW, buffer, size, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_GetReceiveStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetReceiveStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetReceiveStatus(void)
{
    return Cy_SCB_UART_GetReceiveStatus(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_AbortReceive
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_AbortReceive() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_AbortReceive(void)
{
    Cy_SCB_UART_AbortReceive(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_GetNumReceived
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetNumReceived() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetNumReceived(void)
{
    return Cy_SCB_UART_GetNumReceived(UART_BCP_HW, &UART_BCP_context);
}
#endif /* (UART_BCP_ENABLE_RX) */


#if (UART_BCP_ENABLE_TX)
/*******************************************************************************
* Function Name: UART_BCP_Transmit
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Transmit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_scb_uart_status_t UART_BCP_Transmit(void *buffer, uint32_t size)
{
    return Cy_SCB_UART_Transmit(UART_BCP_HW, buffer, size, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_GetTransmitStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetTransmitStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetTransmitStatus(void)
{
    return Cy_SCB_UART_GetTransmitStatus(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_AbortTransmit
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_AbortTransmit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_AbortTransmit(void)
{
    Cy_SCB_UART_AbortTransmit(UART_BCP_HW, &UART_BCP_context);
}


/*******************************************************************************
* Function Name: UART_BCP_GetNumLeftToTransmit
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_GetNumLeftToTransmit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t UART_BCP_GetNumLeftToTransmit(void)
{
    return Cy_SCB_UART_GetNumLeftToTransmit(UART_BCP_HW, &UART_BCP_context);
}
#endif /* (UART_BCP_ENABLE_TX) */


/*******************************************************************************
* Function Name: UART_BCP_Interrupt
****************************************************************************//**
*
* Invokes the Cy_SCB_UART_Interrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void UART_BCP_Interrupt(void)
{
    Cy_SCB_UART_Interrupt(UART_BCP_HW, &UART_BCP_context);
}

#if defined(__cplusplus)
}
#endif

#endif /* UART_BCP_CY_SCB_UART_PDL_H */


/* [] END OF FILE */
