#include "chip_init.h"
#include "define.h"
#include "project.h"
#include "motor_ctrl.h"


/******************************************************************************
*																			  *
*   Function:    PWM_Start											  			  *
*																			  *
*   Description: Init three TCPWM modules PWMU PWMV PWMW					  	  *
*																			  *				
*   Parameters:   None														  	  *
*																			  *
*   Returns:     None														  	  *		
*																			  *		
******************************************************************************/

void PWM_Start()
{
    /* start 3 phases PWM	*/
    uint8 enableInterrupts;
	/*GPIO set to low*/
	PWM_Ctrl_Reg_Write(0);
	
    (void) Cy_TCPWM_PWM_Init(PWM_A_HW, PWM_A_CNT_NUM, &PWM_A_config);
    (void) Cy_TCPWM_PWM_Init(PWM_B_HW, PWM_B_CNT_NUM, &PWM_B_config);
    (void) Cy_TCPWM_PWM_Init(PWM_C_HW, PWM_C_CNT_NUM, &PWM_C_config);
    (void) Cy_TCPWM_PWM_Init(PWM_D_HW, PWM_D_CNT_NUM, &PWM_D_config);
    
    //PWM_B_Init();
    //PWM_C_Init();
    //PWM_D_Init();
    
    /* clear counter value after start PWM	*/
    
    Cy_TCPWM_PWM_SetCounter(PWM_A_HW, PWM_A_CNT_NUM, 0);
    Cy_TCPWM_PWM_SetCounter(PWM_B_HW, PWM_B_CNT_NUM, 0);
    Cy_TCPWM_PWM_SetCounter(PWM_C_HW, PWM_C_CNT_NUM, 0);
    Cy_TCPWM_PWM_SetCounter(PWM_D_HW, PWM_D_CNT_NUM, 0);
    
    //PWMU_WriteCounter(0);
    //PWMV_WriteCounter(0);
    //PWMW_WriteCounter(0);
    //PWM_D_WriteCounter(0);

	MotorCtrl_ConfigPwm();
    /* disable GPIO output as default, enable later based on firmware	*/
	CyDelay(1);
	
    enableInterrupts = CyEnterCriticalSection();
	
	//PWM_A_BLOCK_CONTROL_REG |= (PWM_A_MASK|PWM_B_MASK|PWM_C_MASK|PWM_D_MASK);
  
    CyExitCriticalSection(enableInterrupts);  

    /* synchronized start three PWMs */
   
	//PWMU_TriggerCommand(0x0F, PWM_A_CMD_RELOAD); 
    
    PWM_A_TriggerReload();

}
/******************************************************************************
*																			  *
*   Function:    PWM_Stop											  			  *
*																			  *
*   Description: Disable three TCPWM modules PWMU PWMV PWMW					  	  *
*																			  *				
*   Parameters:   None														  	  *
*																			  *
*   Returns:     None														  	  *		
*																			  *		
******************************************************************************/
void PWM_Stop()
{

	uint8 enableInterrupts;
		
	PWM_Ctrl_Reg_Write(0);
		
	enableInterrupts = CyEnterCriticalSection();

	//PWM_A_BLOCK_CONTROL_REG &= (uint32)~(PWM_A_MASK|PWM_B_MASK|PWM_C_MASK);

	CyExitCriticalSection(enableInterrupts);

}
/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_ConfigPwm								  							*
*																			  			*
*   Description: TCPWM modules parameters init													*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/
void MotorCtrl_ConfigPwm(void)
{

    int32_t temp_period;
    if (Motor_u16CarrierFreq < 5000)       /*min carry frequency limit*/
    {
        Motor_u16CarrierFreq = 5000;
    }
    else if (Motor_u16CarrierFreq > 20000) /*max carry frequency limit*/
    {
        Motor_u16CarrierFreq = 20000;
    }
	
    temp_period = PWM_FREQUENCY/Motor_u16CarrierFreq/2;
    
    Cy_TCPWM_Counter_SetPeriod(PWM_A_HW, PWM_A_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetPeriod(PWM_B_HW, PWM_B_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetPeriod(PWM_C_HW, PWM_C_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetPeriod(PWM_D_HW, PWM_D_CNT_NUM, (temp_period << 1) - 1);
    
    //PWMU_WritePeriod(temp_period);
	//PWMV_WritePeriod(temp_period);
	//PWMW_WritePeriod(temp_period);
    //PWM_D_WritePeriod((temp_period << 1) - 1);
	
    int pwmaperiod = Cy_TCPWM_Counter_GetPeriod(PWM_A_HW, PWM_A_CNT_NUM);
    
	if((Cy_TCPWM_Counter_GetPeriod(PWM_A_HW, PWM_A_CNT_NUM) != Cy_TCPWM_Counter_GetPeriod(PWM_B_HW, PWM_B_CNT_NUM)) || (Cy_TCPWM_Counter_GetPeriod(PWM_A_HW, PWM_A_CNT_NUM) != Cy_TCPWM_Counter_GetPeriod(PWM_C_HW, PWM_C_CNT_NUM)))
	{
	    MotorCtrl_stcRunPar.u32ErroType |= UNDEFINED_INT;
        MotorCtrl_Stop();
	}
	
    if (Motor_f32DeadTimeMicroSec < 0.5)   /*dead time min limit unit: us*/
    {
        Motor_f32DeadTimeMicroSec = 0.5;
    }
    

	PWMU_SetPWMDeadTime((int32_t)(Motor_f32DeadTimeMicroSec * PWM_FREQUENCY_48M));
	PWMV_SetPWMDeadTime((int32_t)(Motor_f32DeadTimeMicroSec * PWM_FREQUENCY_48M));
	PWMW_SetPWMDeadTime((int32_t)(Motor_f32DeadTimeMicroSec * PWM_FREQUENCY_48M));
    
    Cy_TCPWM_Counter_SetCompare0(PWM_A_HW, PWM_A_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetCompare0(PWM_B_HW, PWM_B_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetCompare0(PWM_C_HW, PWM_C_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetCompare0(PWM_D_HW, PWM_D_CNT_NUM, (temp_period << 1) - 24);
    
    //PWMU_WriteCompare(temp_period);
    //PWMV_WriteCompare(temp_period);
    //PWMW_WriteCompare(temp_period);
    //PWM_D_WriteCompare((temp_period << 1) - 24);
    
    Cy_TCPWM_Counter_SetCompare1(PWM_A_HW, PWM_A_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetCompare1(PWM_B_HW, PWM_B_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetCompare1(PWM_C_HW, PWM_C_CNT_NUM, temp_period);
    Cy_TCPWM_Counter_SetCompare1(PWM_D_HW, PWM_D_CNT_NUM, (temp_period << 1) - 24);
    
    //PWMU_WriteCompareBuf(temp_period);
    //PWMV_WriteCompareBuf(temp_period);
    //PWMW_WriteCompareBuf(temp_period);
    //PWM_D_WriteCompareBuf((temp_period << 1) - 24);
	
	MotorCtrl_stcSvmGen.i16Cycle = Cy_TCPWM_Counter_GetPeriod(PWM_A_HW, PWM_A_CNT_NUM);
    MotorCtrl_stcSvmGen.i16DutyMax = Q0(MotorCtrl_stcSvmGen.i16Cycle - (PWM_FREQUENCY_48M * 2.6));
    MotorCtrl_stcSvmGen.i16DeadTime = Q0(Motor_f32DeadTimeMicroSec* PWM_FREQUENCY_48M);

}

/* [] END OF FILE */
