#include <project.h>
#include <stdio.h>
#include "interface.h"
#include "motor_ctrl.h"
#include "define.h"
#include "math.h" 
#include "motor_ctrl.h"
#include "observer_pll.h"
#include "motor_startup.h"

static uint8 bcpTxBuffer[32];

/****************************************************************************************
*																			  			*
*   Function:    BCPPoll								  								*
*																			  			*
*   Description: BCPPoll routine   													    *
*				 Format:  RX8 [h=55] @0speed @1speed @0currentU @1currentU [t=AA]       *				
*   Parameters:   None																	*
*				  							  			                                *
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/

void BCPPoll()
{
	uint8 index = 0;
	int32 temp;
    
	//if(UART_BCP_SpiUartGetTxBufferSize())
	//	return;
    
    if (Cy_SCB_SPI_GetNumInTxFifo(UART_BCP_HW))
        return;
    
    //temp = (uint16_t)(Counter);
    temp = (uint16_t) (encoder.i32Q10_ThetaAbs);
    //temp = MotorCtrl_stcRunPar.u32ErroType ? MotorCtrl_stcRunPar.u32ErroType : (MotorCtrl_stcRunPar.i32TargetSpeedRpm);
    //temp = (uint16_t) (encoder.i32_SpeedRPMf);//MotorCtrl_stcIqPidReg.i32_Out);
    bcpTxBuffer[index++] = (temp >> 8)&0xFF;
	bcpTxBuffer[index++] = (temp)&0xFF;
    
    //temp = (uint16_t)(encoder.i16Q10_Theta);
    //temp = (uint16_t) (encoder.i32Q22_ThetaElec>>6);
    //temp = (uint16_t)(MotorCtrl_stcIdqSensed.i32Q8_Xq);
    temp = (uint16_t) MotorCtrl_stcIdqRef.i32Q8_Xq;
	bcpTxBuffer[index++] = (temp >> 8)&0xFF;
	bcpTxBuffer[index++] = (temp)&0xFF;
    
    //temp = (uint16_t) (synchroFlag<<10 | MotorCtrl_stcRunPar.u32ErroType);
    temp = (uint16_t) MotorCtrl_stcVdqRef.i32Q8_Xq;//(aux>>12);//
    //temp = (uint16_t) aux>>6;
    //temp = (uint16_t) MotorCtrl_stcIuvwSensed.i32Q8_Xu;
	bcpTxBuffer[index++] = (temp >> 8)&0xFF;
	bcpTxBuffer[index++] = (temp)&0xFF;
    
    /*
    temp = (uint16_t) MotorCtrl_stcIuvwSensed.i32Q8_Xw;
	bcpTxBuffer[index++] = (temp >> 8)&0xFF;
	bcpTxBuffer[index++] = (temp)&0xFF;
    */
    
    // Tail
	bcpTxBuffer[index++] = 0x0A;
	bcpTxBuffer[index++] = 0x0D;
    
	//UART_BCP_SpiUartPutArray(bcpTxBuffer, index);
    Cy_SCB_UART_PutArray(UART_BCP_HW, bcpTxBuffer, index);
	
}


/****************************************************************************************
*																			  			*
*   Function:    BCPRead								  								*
*																			  			*
*   Description: Reads data from the UART   										    *
*				 Format:  RX8 [h=55] @0speed @1speed @0currentU @1currentU [t=AA]       *				
*   Parameters:   None																	*
*				  							  			                                *
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/
void BCPRead()
{
    uint8_t pack_type, pack_size, index;
    uint8_t pack[16];
    
    // Check if there is enough data
    //if(UART_BCP_SpiUartGetRxBufferSize() < 2)
    //    return;
    
    if(Cy_SCB_SPI_GetNumInRxFifo(UART_BCP_HW) < 2)
        return;
    
    // Get header
    pack_type = Cy_SCB_UART_Get(UART_BCP_HW);
    pack_size = Cy_SCB_UART_Get(UART_BCP_HW);
    // Wait for enough bytes
    while(UART_BCP_SpiUartGetRxBufferSize() < pack_size);
    for(index = 0; index<pack_size; index++)
    {
        pack[index] = UART_BCP_UartGetByte();
    }
    
    // Execute the command received
    UART_BCP_SpiUartClearRxBuffer();
    RunCommand(pack_type,pack_size,pack);
	

}

/****************************************************************************************
*																			  			*
*   Function:    RunCommand								  								*
*																			  			*
*   Description: Runs the command received through UART                                      *
*				                                                                        *				
*   Parameters:   pack type, pack size, pack data																	*
*				  							  			                                *
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/
void RunCommand(uint8_t type, uint8_t size, uint8_t * data)
{    
    uint32_t temp=0;
    
    switch(type)
    {        
        // Start / Stop command
        case CMD_START:
            Running = data[0];
            break;
        
        // Control loop command
        case CMD_CONTROL: 
            Motor_Control = data[0];
            break;
        
        // Change PID parameters
        case CMD_PID:
            temp = data[2];
            temp = (temp<<8) | data[3];
            temp = (temp<<8) | data[4];
            temp = (temp<<8) | data[5];
        
        switch(data[0])     // Speed, current or position
        {
            case CMD_PID_SPD: //Speed
                switch(data[1]) // Kp, Ki or Kd
                {
                    case CMD_PID_KP:
                        MotorCtrl_stcWmPidReg.i32Q15_kp = temp;  
                        Motor_f32LowSpdKp = (float32_t) temp/0x8000;
                        break;
                    case CMD_PID_KI: 
                        MotorCtrl_stcWmPidReg.i32Q15_ki = temp;  
                        Motor_f32LowSpdKi = (float32_t) temp/0x8000;  
                        break;
                    case CMD_PID_KD:
                        MotorCtrl_stcWmPidReg.i32Q15_kd = temp; 
                        Motor_f32LowSpdKd = (float32_t) temp/0x8000;   
                        break;
                }
            break;
            
            case CMD_PID_CUR: //Current
                switch(data[1]) // Kp, Ki or Kd
                {
                    case CMD_PID_KP:
                        MotorCtrl_stcIdPidReg.i32Q15_kp = temp; 
                        MotorCtrl_stcIqPidReg.i32Q15_kp = temp; 
                        Motor_f32Dkp = (float32_t) temp/0x8000;
                        Motor_f32Qkp = (float32_t) temp/0x8000;
                        break;
                    case CMD_PID_KI: 
                        MotorCtrl_stcIdPidReg.i32Q15_ki = temp; 
                        MotorCtrl_stcIqPidReg.i32Q15_ki = temp;
                        Motor_f32Dki = (float32_t) temp/0x8000;
                        Motor_f32Qki = (float32_t) temp/0x8000;
                        break;
                    case CMD_PID_KD:
                        MotorCtrl_stcIdPidReg.i32Q15_kd = temp;   
                        MotorCtrl_stcIqPidReg.i32Q15_kd = temp;
                        Motor_f32Dkd = (float32_t) temp/0x8000;
                        Motor_f32Qkd = (float32_t) temp/0x8000;
                        break;
                }
            break;
            
            case CMD_PID_POS: //Position
                switch(data[1]) // Kp, Ki or Kd
                {
                    case CMD_PID_KP:
                        MotorCtrl_stcPosPidReg.i32Q15_kp = temp; 
                        Motor_f32PosKp = (float32_t) temp/0x8000;
                        break;
                    case CMD_PID_KI: 
                        MotorCtrl_stcPosPidReg.i32Q15_ki = temp; 
                        Motor_f32PosKi = (float32_t) temp/0x8000;
                        break;
                    case CMD_PID_KD:
                        MotorCtrl_stcPosPidReg.i32Q15_kd = temp; 
                        Motor_f32PosKd = (float32_t) temp/0x8000;
                        break;
                }
            break;
        }
        break;
                 
        // Control reference mode
        case CMD_REF:
            Ref_Mode = data[0];
            break;
        
        // Reference input period
        case CMD_PER:
            Ref_Period = data[3];
            Ref_Period = (Ref_Period<<8) | data[2];
            Ref_Period = (Ref_Period<<8) | data[1];
            Ref_Period = (Ref_Period<<8) | data[0];
            Ref_Period_s = Ref_Period/Motor_u16CarrierFreq;
            break;
            
        // Reference input amplitude
        case CMD_AMP:
            temp = data[3];
            temp = (temp<<8) | data[2];
            temp = (temp<<8) | data[1];
            temp = (temp<<8) | data[0];
            
            switch(Motor_Control)
            {
                case SPD_CTRL:
                    Motor_i16SpdAmp = temp;
                    break;
                case CUR_CTRL:
                    Motor_i16Q8_IqAmp = temp;
                    break;
                case POS_CTRL:
                    Motor_i32_PosAmp = temp;
                    break;
            }
            break;
            
        // Reference input offset
        case CMD_OFF:
            temp = data[3];
            temp = (temp<<8) | data[2];
            temp = (temp<<8) | data[1];
            temp = (temp<<8) | data[0];
            
            switch(Motor_Control)
            {
                case SPD_CTRL:
                    Motor_i16SpdOffset = temp;
                    break;
                case CUR_CTRL:
                    Motor_i16Q8_IqOffset = temp;
                    break;
                case POS_CTRL:
                    Motor_i32_PosOffset = temp;
                    break;
            }
            break;
        
    }
    
    // Reset the loop
    MotorCtrl_Stop();
	
}


/* [] END OF FILE */
