/*****************************************************************************/
/* Include files                                                             */
/****************************************************************************

#include <project.h>

#include "hardware_config.h"
#include "isr.h"
#include "interface.h"

#include "adc_sample.h"
#include "define.h"



/*****************************************************************************/
/* Local pre-processor symbols/macros ('#define')                            */
/*****************************************************************************/

/*****************************************************************************/
/* Global variable definitions (declared in header file with 'extern')       */
/*****************************************************************************/

/*****************************************************************************/
/* Local type definitions ('typedef')                                        */
/*****************************************************************************/

/*****************************************************************************/
/* Local variable definitions ('static')                                     */
/*****************************************************************************
int32_t u;
int32_t w;
uint32_t Led_CountTime = 0;

/*****************************************************************************/
/* Local function prototypes ('static')                                      */
/*****************************************************************************/

/*****************************************************************************/
/* Function implementation - global ('extern') and local ('static')          */
/*****************************************************************************/

/****************************************************************************************
*																			  			*
*   Function:    FOC_MainLoop_ISR								  							*
*																			  			*
*   Description: PWM main ISR, implement base FOC flow											*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************
CY_ISR(FOC_MainLoop_ISR)
{
    uint32_t Clear_ISR;

    Clear_ISR = PWM_C_GetInterruptSourceMasked();
    
    Pin_Debug_Write(0x01);
	 MotorCtrl_Process();           // Main control 
    BCPPoll();
    Pin_Debug_Write(0x00);
    
    PWM_C_ClearInterrupt(Clear_ISR);
}
/****************************************************************************************
*																			  			*
*   Function:    Ibus_Over_ISR								  								*
*																			  			*
*   Description: comparator ISR for bus current over protection										*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
***************************************************************************************
CY_ISR(Ibus_Over_ISR)
{
	LPComp_ClearInterrupt(LPComp_INTR);
	if(LPComp_GetCompare())
	{
		MotorCtrl_stcRunPar.u32ErroType = MOTOR_OVER_CURRENT;
		MotorCtrl_Stop();
		LPComp_ClearInterrupt(LPComp_INTR);
	}
	LPComp_ClearInterrupt(LPComp_INTR);
}

/****************************************************************************************
*																			  			*
*   Function:    AD_Time_ISR								  									*
*																			  			*
*   Description: ADC ISR, sampling ADC value													*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************
CY_ISR(AD_Time_ISR)
{

	 uint32 intr_status;

		/* Read interrupt status register */
        //intr_status = ADC_SAR_INTR_REG;
        
        /************************************************************************
        *  Custom Code
        *  - add user ISR code between the following #START and #END tags
        *************************************************************************/
        /* `#START MAIN_ADC_ISR`  *
			Adc_ReadSample();       // Updates Adc_u16RsltOfAdc vector
		
			u = Adc_u16RsltOfAdc[0];
	        w = Adc_u16RsltOfAdc[1];
			MotorCtrl_stcRunPar.i32Q8_Vbus = (Adc_u16RsltOfAdc[SYS_ADC_CH_VDC]* Adc_stcSample.i32Q12_Vbusk)>>6;
			MotorCtrl_stcRunPar.i32Q8_VR = (Adc_u16RsltOfAdc[MOTOR_SPEED_VR]);

			if(MotorCtrl_stcSvmGen.i8ShuntNum >= 2)
	    	{
		        if(Adc_u8MotorStatus == SENSOR_RUNNING)
		        {
		               Adc_stcSample.u8_CompleteFlag = 1;
		        }
		        else if(Adc_u8MotorStatus == SENSOR_STOP)
		        {     
		              Adc_MotorSensorOffesetDetect();            
		        }
	    	}
            Led_CountTime++;
            
        /* `#END`  */
        /* Clear handled interrupt /
      //  ADC_SAR_INTR_REG = intr_status;
       
}
    */
