/*****************************************************************************/
/* Include files                                                             */
/*****************************************************************************/
#include <stdlib.h>
#include <project.h>

#include "math.h" 

#include "limitation.h"

#include "motor_ctrl.h"
#include "protect.h"

#include "observer_pll.h"

#include "motor_startup.h"
#include "hardware_config.h"
#include "define.h"
#include "svpwm.h"
#include "chip_init.h"
#include "interface.h"
#include "customer_interface.h"

/*****************************************************************************/
/* Local pre-processor symbols/macros ('#define')                            */
/*****************************************************************************/

/*****************************************************************************/
/* Global variable definitions (declared in header file with 'extern')       */
/*****************************************************************************/

// sample
stc_uvw_t               MotorCtrl_stcIuvwSensed;

// coordinate transformation
stc_ab_t                MotorCtrl_stcIabSensed;
stc_dq_t                MotorCtrl_stcIdqSensed;
stc_dq_t                MotorCtrl_stcVdqRef;
stc_dq_t                MotorCtrl_stcIdqRef;
stc_ab_t                MotorCtrl_stcVabRef;
stc_ab_t                MotorCtrl_stcVabReal;
stc_uvw_t               MotorCtrl_stcVuvwRef;

stc_dq_t                MotorCtrl_stcEdq;
stc_ab_t                MotorCtrl_stcEab;

//stc_Ipd_t               stcIpd;

// LPF

stc_one_order_lpf_t     MotorCtrl_stc1stLpfWm = { Q12(0.1), Q20(0.0) };//0.25

// PID
stc_pid_cfg_t               MotorCtrl_stcIqPidReg;
stc_pid_cfg_t               MotorCtrl_stcIdPidReg;
stc_pid_cfg_t               MotorCtrl_stcWmPidReg;
stc_pid_cfg_t               MotorCtrl_stcPosPidReg;

// PWM
stc_svm_gen_t           MotorCtrl_stcSvmGen;
stc_svm_calc_t          MotorCtrl_stcSvmCalc;

//motor ctrl
stc_motor_run_t         MotorCtrl_stcRunPar;
stc_soft_timers_t       MotorCtrl_stcSoftTimer;

int32_t     MotorCtrl_i32Q12_IsMaxSquare;
int32_t     MotorCtrl_i32Q8_iqMax;

int32_t     MotorCtrl_i32Q8_SpdPiHighWmHz;
int32_t     MotorCtrl_i32Q16_LowSpdPiKi;
int32_t     MotorCtrl_i32Q10_LowSpdPiKp;

int32_t     MotorCtrl_i32VqMax;

//spd loop
stc_spdLoop_t MotorCtrl_SpdLoopCtrl;

// encoder
encoder_t encoder;
uint8_t synchroFlag = 0;
uint16_t synchroCounts = 0;
uint8_t firstCycle = 1;
int32_t aux;
int32_t thetaAbsPre;

// Position control
int32_t position_ref=0;

// Reference trajectory
uint32_t ref_counter = 0;

// System control
uint8_t Running = 1;
uint16_t Counter = 0;

// PID 32-bit
Pid32_t PosPidCfg;
Pid32_t IqPidCfg;
Pid32_t IdPidCfg;
int32_t iq_out, id_out;


/*****************************************************************************/
/* Local type definitions ('typedef')                                        */
/*****************************************************************************/

/*****************************************************************************/
/* Local variable definitions ('static')                                     */
/*****************************************************************************/

/*****************************************************************************/
/* Local function prototypes ('static')                                      */
/*****************************************************************************/
static void MotorCtrl_InitPar(uint16_t u16SampleFreq);
static void MotorCtrl_SpdReg(void);
static void MotorCtrl_ThetaGen(void);

/*****************************************************************************/
/* Function implementation - global ('extern') and local ('static')          */
/*****************************************************************************/


/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_Init								  									*
*																			  			*
*   Description: Init for motorctrl parameters													*
*																			  			*				
*   Parameters:   u16SampleFreq																*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

void MotorCtrl_Init(uint16_t u16SampleFreq)
{
    MotorCtrl_stcSvmGen.i8ShuntNum = MOTOR_SHUNT_NUM;

    Adc_InitSensorPar(u16SampleFreq);
    
}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_Start								  								*
*																			  			*
*   Description: Init for start parameters														*
*																			  			*				
*   Parameters:   u16SampleFreq																*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

void MotorCtrl_Start(uint16_t u16SampleFreq)
{
	Protector_Init(u16SampleFreq);
	MotorCtrl_InitPar(u16SampleFreq);
	FieldWeaken_Init(u16SampleFreq);        
	MotorStart_Init(&MotorCtrl_stcStartup);
	CV_LimitInit(&CV_LimitPars);        

	MotorCtrl_InitPll(u16SampleFreq);

	// init SVPWM
	stc_svm_cfg_t stc_SvmGenCfg;
	stc_SvmGenCfg.u16Cycle   = MotorCtrl_stcSvmGen.i16Cycle;
	stc_SvmGenCfg.u16DutyMax = MotorCtrl_stcSvmGen.i16DutyMax;
	stc_SvmGenCfg.u16DpwmEn  = 0;
	Svm_InitCalc(&stc_SvmGenCfg,&MotorCtrl_stcSvmCalc);


	if (SENSOR_RUNNING == Adc_u8MotorStatus)
	{	
        Pin_Led_Write(LED_ON);
		PWM_Start();
		MotorCtrl_stcRunPar.u8Status = MOTOR_RUNNING; 
		PWM_Ctrl_Reg_Write(1);       
	}

}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_Stop								  								*
*																			  			*
*   Description: set for stop parameters														*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

//int32_t stop_flag = 0;

void MotorCtrl_Stop(void)
{

    //InitMcu_MotorSvmDis();
    MotorCtrl_stcRunPar.u8Status = MOTOR_STOP;
    MotorCtrl_stcRunPar.i32TargetSpeedRpm = 0;
    MotorCtrl_stcRunPar.i32Q8_EstimWmHz = 0;
    MotorCtrl_stcRunPar.i32Q8_EstimWmHzf = 0;
    MotorCtrl_stcIuvwSensed.i32Q8_Xu = 0;
    MotorCtrl_stcIuvwSensed.i32Q8_Xv = 0;
    MotorCtrl_stcIuvwSensed.i32Q8_Xw = 0;
    
    Encoder_Stop(); //
    ref_counter = 0;//
    PosPidCfg.i32_ErrPre = 0;
    PosPidCfg.i32_Integral = 0;
    PosPidCfg.i8_Sat = 0;
    
	PWM_Stop();
    Pin_Led_Write(LED_OFF);
    /*
    for(uint8_t i = 0;i<64;i++)
    {
        Temp_Speed[i] = 0;
    }
    temp_OutFilter = 0;
    */
	/*prevent running restart*/
	CyDelay(200);

}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_Protect								  								*
*																			  			*
*   Description: Motor Protect function															*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

void MotorCtrl_Protect(void)
{
	
    Protector_LockPar.i32_Edf = MotorCtrl_stcEdq.i32Q8_Xd;//i32_Edf;
    Protector_LockPar.i32_Eqf = MotorCtrl_stcEdq.i32Q8_Xq;//i32_Eqf;

    if(MOTOR_RUNNING == MotorCtrl_stcRunPar.u8Status)
    {

        MotorCtrl_stcRunPar.u32ErroType |= MotorProtect_OutRange(&Protector_OutRangePar,&MotorCtrl_stcIuvwSensed, MotorCtrl_stcRunPar.i32Q8_Vbus);

        if(MotorCtrl_stcRunPar.u8RunningStage < FORCE_STARTUP)
        {			
                //MotorCtrl_stcRunPar.u32ErroType |= MotorProtect_LosePhase1(&Protector_NoneLoadPar,&MotorCtrl_stcIuvwSensed,&MotorCtrl_stcIdqRef);
        }                              
    }
    else
    {
        if(0 != MotorCtrl_stcRunPar.u32ErroType)
        {
                if(++Protector_FlgClr.i32_ErrorFlagHoldTimeCnt
                   > Protector_FlgClr.i32_ErrorFlagHoldTimeNum)
                {
                       // MotorCtrl_stcRunPar.u32ErroType = 0;
                        Protector_FlgClr.i32_ErrorFlagHoldTimeCnt = 0;
                }
        }
    }
}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_InitPar								  								*
*																			  			*
*   Description: Init for same parameters before motor run										*
*																			  			*				
*   Parameters:   u16SampleFreq																*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

static void MotorCtrl_InitPar(uint16_t u16SampleFreq)
{
    Motor_u16SpdMax = Motor_i16SpdOffset + Motor_i16SpdAmp;
    Motor_u16SpdMin = Motor_i16SpdOffset - Motor_i16SpdAmp;
 
    MotorCtrl_stcRunPar.i32Q8_EstimWmHzf       = 0;
    MotorCtrl_stcRunPar.i32Q22_DeltaThetaKTs   = Q22(1.0*Motor_i32PolePairs/u16SampleFreq);
    MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz  = Q8(Motor_u16ColseLoopTargetSpdHz);
    MotorCtrl_stcRunPar.i32Q22_TargetSpeedWmHz = Q22(Motor_u16ColseLoopTargetSpdHz);
    MotorCtrl_stcRunPar.i32Q22_TargetWmIncTs   = Q22(Motor_f32SpdAccelerationHz * 3.0/u16SampleFreq);
    MotorCtrl_stcRunPar.i32Q22_TargetWmDecTs   = Q22(Motor_f32SpdDecelerationHz * 3.0/u16SampleFreq);
    MotorCtrl_stcRunPar.i32TargetSpeedRpmMax   = Q0(Motor_i16SpdOffset+Motor_i16SpdAmp);//Motor_u16SpdMax);
    MotorCtrl_stcRunPar.i32TargetSpeedRpmMin   = Q0(Motor_i16SpdOffset-Motor_i16SpdAmp);
    MotorCtrl_stcRunPar.i32Q22_ElecAngle = Q22(0.0);
    MotorCtrl_stcRunPar.u32ErroType      = 0;
    MotorCtrl_stcRunPar.u8SpeedPiEn      = 0;
    MotorCtrl_stcRunPar.u8StartupCompleteFlag = 0;
    MotorCtrl_stcRunPar.u8RunningStage   = MOTOR_ORIENTATION;
    MotorCtrl_stcRunPar.u8Runninglevel   = Motor_u8RunLevel;
    MotorCtrl_stcRunPar.u8CloseloopFlag  = 0;
    MotorCtrl_stcRunPar.u8ChangeSpeedEn  = 0;
    MotorCtrl_stcRunPar.u8ChangePiParEn  = 0;
    MotorCtrl_stcRunPar.u8SpeedPiMode    = 0;
    MotorCtrl_stcSoftTimer.u32Timer0     = 0;
    MotorCtrl_stcSoftTimer.i32Timer1     = 0;
    MotorCtrl_stcSoftTimer.i32Timer2     = 0;
    MotorCtrl_stcSoftTimer.i32Timer3     = 0;
    MotorCtrl_stcIdqRef.i32Q8_Xd = Q8(0.0f);
    MotorCtrl_stcIdqRef.i32Q8_Xq = Q8(0.0f);
    MotorCtrl_stcVabRef.i32Q8_Xa = Q8(0.0f);
    MotorCtrl_stcVabRef.i32Q8_Xb = Q8(0.0f);
    MotorCtrl_stcVdqRef.i32Q8_Xd = Q8(0.0f);
    MotorCtrl_stcVdqRef.i32Q8_Xq = Q8(0.0f);
	

    MotorCtrl_stcSvmGen.i8ShuntNum = MOTOR_SHUNT_NUM;
    MotorCtrl_stcSvmGen.i16T1      = 0;
    MotorCtrl_stcSvmGen.i16T2      = 0;

    MotorCtrl_stcSvmGen.i16AdcTrigT2 = MotorCtrl_stcSvmGen.i16DutyMax - 240;
    MotorCtrl_stcSvmGen.i16AdcTirgT1 = MotorCtrl_stcSvmGen.i16DutyMax >> 1;
    MotorCtrl_stcSvmGen.i16SampleWind = 320;//480;
    MotorCtrl_stcSvmGen.i16SampleOffeset = 100;//220;

    MotorCtrl_i32Q8_iqMax        = Motor_i16Q8_CloseLoopIqRefMax;
    MotorCtrl_i32Q12_IsMaxSquare = (Motor_i16Q8_CloseLoopIsMax
                             * Motor_i16Q8_CloseLoopIsMax) >> 4;

    MotorCtrl_i32Q8_SpdPiHighWmHz = Q8(Motor_u16ChgPiSpdHz);
    MotorCtrl_i32Q16_LowSpdPiKi   = Q16(Motor_f32LowSpdKi);
    MotorCtrl_i32Q10_LowSpdPiKp   = Q10(Motor_f32LowSpdKp);

    // init speed regulator
  
    MotorCtrl_stcIdPidReg.i32Q15_kp = Q15(Motor_f32Dkp);
    MotorCtrl_stcIdPidReg.i32Q15_ki = Q15(Motor_f32Dki);
    MotorCtrl_stcIdPidReg.i32Q15_kd = Q15(Motor_f32Dkd);
    MotorCtrl_stcIdPidReg.i32_OutMax = Q8(15);//200 15
    MotorCtrl_stcIdPidReg.i32_OutMin = Q8(-15);//-200 -15
    MotorCtrl_stcIdPidReg.i32QN_Iout = 0;
    MotorCtrl_stcIdPidReg.i32_E0  = Q8(0);
    MotorCtrl_stcIdPidReg.i32_E1  = Q8(0);
    MotorCtrl_stcIdPidReg.i32_Iout = Q8(0);
    MotorCtrl_stcIdPidReg.i32_Out  = Q8(0);
    MotorCtrl_stcIdPidReg.i32_OutPre = 0;
    MotorCtrl_stcIdPidReg.i32_Pout = 0;
    MotorCtrl_stcIdPidReg.i32_E0Max = Q8(5); //Q8(10) Q8(5)
    MotorCtrl_stcIdPidReg.i32_E0Min = Q8(-5); //Q8(-10) Q8(-5)
    
    MotorCtrl_stcIqPidReg.i32Q15_kp = Q15(Motor_f32Qkp);
    MotorCtrl_stcIqPidReg.i32Q15_ki = Q15(Motor_f32Qki);
    MotorCtrl_stcIqPidReg.i32Q15_kd = Q15(Motor_f32Qkd);
    MotorCtrl_stcIqPidReg.i32_OutMax = Q8(15);//200 15
    MotorCtrl_stcIqPidReg.i32_OutMin = Q8(-15);//-200 0             //Modified. Before: 0
    MotorCtrl_stcIqPidReg.i32QN_Iout = 0;
    MotorCtrl_stcIqPidReg.i32_E0  = Q8(0);
    MotorCtrl_stcIqPidReg.i32_E1  = Q8(0);
    MotorCtrl_stcIqPidReg.i32_Iout = Q8(0);
    MotorCtrl_stcIqPidReg.i32_Out  = Q8(0);
    MotorCtrl_stcIqPidReg.i32_OutPre = 0;
    MotorCtrl_stcIqPidReg.i32_Pout = 0;
    MotorCtrl_stcIqPidReg.i32_E0Max = Q8(5); //Q8(10) Q8(5)
    MotorCtrl_stcIqPidReg.i32_E0Min = Q8(-5);//Q8(-10) Q8(-5)
   
    MotorCtrl_stcWmPidReg.i32Q15_kp = Q15(Motor_f32LowSpdKp);
    MotorCtrl_stcWmPidReg.i32Q15_ki = Q15(Motor_f32LowSpdKi);
    MotorCtrl_stcWmPidReg.i32Q15_kd = Q15(Motor_f32LowSpdKd);
    MotorCtrl_stcWmPidReg.i32_OutMax = Motor_i16Q8_CloseLoopIqRefMax;
    MotorCtrl_stcWmPidReg.i32_OutMin = -Motor_i16Q8_CloseLoopIqRefMax;      // Modified. Before: 0
    MotorCtrl_stcWmPidReg.i32QN_Iout = 0;
    MotorCtrl_stcWmPidReg.i32_E0  = Q8(0);
    MotorCtrl_stcWmPidReg.i32_E1  = Q8(0);
    MotorCtrl_stcWmPidReg.i32_Iout = Q8(0);
    MotorCtrl_stcWmPidReg.i32_Out  = Q8(0);
    MotorCtrl_stcWmPidReg.i32_OutPre = 0;
    MotorCtrl_stcWmPidReg.i32_Pout = 0;
    MotorCtrl_stcWmPidReg.i32_Dout = 0;
    MotorCtrl_stcWmPidReg.i32_E0Max = Q8(10);//100  10
    MotorCtrl_stcWmPidReg.i32_E0Min = Q8(-10);//-100  -10
    MotorCtrl_stcWmPidReg.I_cnt = 0;
    MotorCtrl_stcWmPidReg.I_timer = 1;
    
    MotorCtrl_stcPosPidReg.i32Q15_kp = Q15(Motor_f32PosKp);
    MotorCtrl_stcPosPidReg.i32Q15_ki = Q15(Motor_f32PosKi);
    MotorCtrl_stcPosPidReg.i32Q15_kd = Q15(Motor_f32PosKd);
    MotorCtrl_stcPosPidReg.i32_OutMax = Motor_i16Q8_CloseLoopIqRefMax;
    MotorCtrl_stcPosPidReg.i32_OutMin = -Motor_i16Q8_CloseLoopIqRefMax;      // Modified. Before: 0
    MotorCtrl_stcPosPidReg.i32QN_Iout = 0;
    MotorCtrl_stcPosPidReg.i32_E0  = Q8(0);
    MotorCtrl_stcPosPidReg.i32_E1  = Q8(0);
    MotorCtrl_stcPosPidReg.i32_Iout = Q8(0);
    MotorCtrl_stcPosPidReg.i32_Out  = Q8(0);
    MotorCtrl_stcPosPidReg.i32_OutPre = 0;
    MotorCtrl_stcPosPidReg.i32_Pout = 0;
    MotorCtrl_stcPosPidReg.i32_Dout = 0;
    MotorCtrl_stcPosPidReg.i32_E0Max = Q8(10);//100  10
    MotorCtrl_stcPosPidReg.i32_E0Min = Q8(-10);//-100  -10
    MotorCtrl_stcPosPidReg.I_cnt = 0;
    MotorCtrl_stcPosPidReg.I_timer = 1;
    
    PosPidCfg.i32_Kp = Q15(Motor_f32PosKp);
    PosPidCfg.i32_Ki = Q15(Motor_f32PosKi);
    PosPidCfg.i32_Kd = Q15(Motor_f32PosKd);
    PosPidCfg.i32_OutMax = Motor_i16Q8_CloseLoopIqRefMax;
    PosPidCfg.i32_OutMin = -Motor_i16Q8_CloseLoopIqRefMax;
    PosPidCfg.i8_Sat = 0;
    PosPidCfg.i32_Out = 0;
    PosPidCfg.i32_ErrPre = 0;
    PosPidCfg.i32_Integral = 0;
    
    IqPidCfg.i32_Kp = Q15(Motor_f32Qkp);
    IqPidCfg.i32_Ki = Q15(Motor_f32Qki);
    IqPidCfg.i32_Kd = Q15(Motor_f32Qkd);
    IqPidCfg.i32_OutMax = VdqMax;
    IqPidCfg.i32_OutMin = VdqMin;
    IqPidCfg.i8_Sat = 0;
    IqPidCfg.i32_Out = 0;
    IqPidCfg.i32_ErrPre = 0;
    IqPidCfg.i32_Integral = 0;
    
    IdPidCfg.i32_Kp = Q15(Motor_f32Dkp);
    IdPidCfg.i32_Ki = Q15(Motor_f32Dki);
    IdPidCfg.i32_Kd = Q15(Motor_f32Dkd);
    IdPidCfg.i32_OutMax = VdqMax;
    IdPidCfg.i32_OutMin = VdqMin;
    IdPidCfg.i8_Sat = 0;
    IdPidCfg.i32_Out = 0;
    IdPidCfg.i32_ErrPre = 0;
    IdPidCfg.i32_Integral = 0;
    
    MotorCtrl_SpdLoopCtrl.i32_LpfMinSpd = Q8(65);
    MotorCtrl_SpdLoopCtrl.i32_LpdMaxSpd = Q8(100);
    MotorCtrl_SpdLoopCtrl.i32Q12_LpfMax = Q12(1.0);
    MotorCtrl_SpdLoopCtrl.i32Q12_LpfMin = Q12(0.1);
    
    if(MotorCtrl_SpdLoopCtrl.i32_LpfMinSpd 
       != MotorCtrl_SpdLoopCtrl.i32_LpdMaxSpd)
    {
       MotorCtrl_SpdLoopCtrl.i32Q8_LpfDelta 
         =  Q8((MotorCtrl_SpdLoopCtrl.i32Q12_LpfMax - MotorCtrl_SpdLoopCtrl.i32Q12_LpfMin))
             /(MotorCtrl_SpdLoopCtrl.i32_LpdMaxSpd - MotorCtrl_SpdLoopCtrl.i32_LpfMinSpd);
       if(MotorCtrl_SpdLoopCtrl.i32Q8_LpfDelta < 0)
       {
          MotorCtrl_SpdLoopCtrl.i32Q8_LpfDelta = 0;
       }
    }
    
    MotorCtrl_SpdLoopCtrl.i32Q8_SpdOut = 0;
    MotorCtrl_SpdLoopCtrl.i32_SpdLoopCnt = 0;
    MotorCtrl_SpdLoopCtrl.i32_SpdLoopCyl = 2; //5
    MotorCtrl_SpdLoopCtrl.SpdOut_lpf.i32Q12_LPFK = Q12(0.3); //Q12(0.3)
    MotorCtrl_SpdLoopCtrl.SpdOut_lpf.i32Q20_LowBits = 0;
    
    // Reference input
    Ref_Period = (uint32_t) Ref_Period_s*Motor_u16CarrierFreq;

}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_SpdReg								  								*
*																			  			*
*   Description: motor speed regulator															*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                               				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

static void MotorCtrl_SpdReg(void)
{
    MotorCtrl_SpdLoopCtrl.i32_SpdLoopCnt ++;
    if(MotorCtrl_SpdLoopCtrl.i32_SpdLoopCnt > MotorCtrl_SpdLoopCtrl.i32_SpdLoopCyl)
    {
        MotorCtrl_SpdLoopCtrl.i32_SpdLoopCnt = 0;
    }
    int32_t Q8_TargetSpeed_Hz_temp;
    Filter_OneOderLpf(MotorCtrl_stcRunPar.i32Q8_EstimWmHz, &MotorCtrl_stcRunPar.i32Q8_EstimWmHzf, &MotorCtrl_stc1stLpfWm);
   //EstHzFlag = MotorCtrl_stcRunPar.i32Q8_EstimWmHz;
    /********************************Motor Target Speed Regulate***************************/
    if (MotorCtrl_stcRunPar.u8ChangeSpeedEn == 1)
    {   
        if(0 != MotorCtrl_stcRunPar.i32TargetSpeedRpm)
        {            
            
            // Check speed ref limits
            if (MotorCtrl_stcRunPar.i32TargetSpeedRpm > MotorCtrl_stcRunPar.i32TargetSpeedRpmMax)
            {
                    MotorCtrl_stcRunPar.i32TargetSpeedRpm = MotorCtrl_stcRunPar.i32TargetSpeedRpmMax;
            }
            else if(MotorCtrl_stcRunPar.i32TargetSpeedRpm< MotorCtrl_stcRunPar.i32TargetSpeedRpmMin)
            {
                    MotorCtrl_stcRunPar.i32TargetSpeedRpm = MotorCtrl_stcRunPar.i32TargetSpeedRpmMin;
            }         
            
            Q8_TargetSpeed_Hz_temp = (MotorCtrl_stcRunPar.i32TargetSpeedRpm<<8)/60;
            if ((Q8_TargetSpeed_Hz_temp - MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz) > (MotorCtrl_stcRunPar.i32Q22_TargetWmIncTs >> 14))
            {
                
                MotorCtrl_stcRunPar.i32Q22_TargetSpeedWmHz += MotorCtrl_stcRunPar.i32Q22_TargetWmIncTs;
                MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz = MotorCtrl_stcRunPar.i32Q22_TargetSpeedWmHz >> 14;
            }
            else if ((Q8_TargetSpeed_Hz_temp - MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz) < -(MotorCtrl_stcRunPar.i32Q22_TargetWmDecTs
                    >> 14))
            {
                
                MotorCtrl_stcRunPar.i32Q22_TargetSpeedWmHz -= MotorCtrl_stcRunPar.i32Q22_TargetWmDecTs;
                MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz = MotorCtrl_stcRunPar.i32Q22_TargetSpeedWmHz >> 14;
            }
            else
            {
               // lpfen = 1;
                MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz = Q8_TargetSpeed_Hz_temp;
            }   
        }
    }
	
    /*******************************Motor Speed Pi Regulate*******************************/ 
	#if 0
    if (MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz > MotorCtrl_i32Q8_SpdPiHighWmHz)
    {
		if (MotorCtrl_stcWmPidReg.i32Q15_kp < (MotorCtrl_i32Q10_HighSpdPiKp<<5))
		{
			MotorCtrl_stcWmPidReg.i32Q15_kp += KP_STEP;
		}

		if (MotorCtrl_stcWmPidReg.i32Q15_ki < (MotorCtrl_i32Q16_HighSpdPiKi>>1))
		{
			MotorCtrl_stcWmPidReg.i32Q15_ki += KI_STEP;
		}
		//MotorCtrl_stcWmPidReg.i32Q15_kp = MotorCtrl_i32Q10_HighSpdPiKp<<5;
		//MotorCtrl_stcWmPidReg.i32Q15_ki = MotorCtrl_i32Q16_HighSpdPiKi>>1;
    }
    else if (MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz < MotorCtrl_i32Q8_SpdPiHighWmHz - Q8(5))
    {
		MotorCtrl_stcWmPidReg.i32Q15_kp = MotorCtrl_i32Q10_LowSpdPiKp<<5;
		MotorCtrl_stcWmPidReg.i32Q15_ki = MotorCtrl_i32Q16_LowSpdPiKi>>1;         
    }
	#endif

	#if 0
    /***********SpdLoop out lpf regulate**************/
    if(MotorCtrl_stcRunPar.i32Q8_EstimWmHzf > MotorCtrl_SpdLoopCtrl.i32_LpfMinSpd)
    {
        MotorCtrl_SpdLoopCtrl.SpdOut_lpf.i32Q12_LPFK 
          = Q12(1) - (((MotorCtrl_stcRunPar.i32Q8_EstimWmHzf - MotorCtrl_SpdLoopCtrl.i32_LpfMinSpd)
            *MotorCtrl_SpdLoopCtrl.i32Q8_LpfDelta) >> 8);
        if(MotorCtrl_SpdLoopCtrl.SpdOut_lpf.i32Q12_LPFK < MotorCtrl_SpdLoopCtrl.i32Q12_LpfMin)
        {
            MotorCtrl_SpdLoopCtrl.SpdOut_lpf.i32Q12_LPFK =  MotorCtrl_SpdLoopCtrl.i32Q12_LpfMin;
        } 
        if(lpfen == 0)
        {
            MotorCtrl_SpdLoopCtrl.SpdOut_lpf.i32Q12_LPFK = Q12(1);
        }
    }
	#endif
	
    /*******************************Motor PI Parameter Regulate***************************/
    if (MotorCtrl_stcRunPar.u8SpeedPiEn == SPEEDPI_RUNNING 
        && MotorCtrl_SpdLoopCtrl.i32_SpdLoopCnt == MotorCtrl_SpdLoopCtrl.i32_SpdLoopCyl)
    {
        MotorCtrl_stcWmPidReg.i32_OutMin = -Motor_i16Q8_CloseLoopIqRefMax; //
        
        MotorCtrl_SpdLoopCtrl.i32_SpdLoopCnt = 0; 

		Pid_Pos(&MotorCtrl_stcWmPidReg,MotorCtrl_stcRunPar.i32Q8_TargetSpeedWmHz-MotorCtrl_stcRunPar.i32Q8_EstimWmHzf);
		
        MotorCtrl_SpdLoopCtrl.i32Q8_SpdOut = MotorCtrl_stcWmPidReg.i32_Out;
        Filter_OneOderLpf(MotorCtrl_SpdLoopCtrl.i32Q8_SpdOut, &MotorCtrl_stcIdqRef.i32Q8_Xq, &MotorCtrl_SpdLoopCtrl.SpdOut_lpf);
        
    } 

}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_ThetaGen								  							*
*																			  			*
*   Description: motor angle generate															*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

static void MotorCtrl_ThetaGen(void)
{
	uint32_t ui32_temp;
	
	if (MotorCtrl_stcRunPar.u8CloseloopFlag == 2)
	{
	    MotorCtrl_stcRunPar.i32Q8_EstimWmHz = Motor_stcPll.i32Q8_EstimWmHz;
	    MotorCtrl_stcRunPar.i32Q22_ElecAngle = (int32_t) (Motor_stcPll.i32Q22_ElecAngle);
	    MotorCtrl_stcRunPar.i32Q22_DeltaThetaTs = Motor_stcPll.i32Q22_DeltaThetaTs;
	}
    else if (MotorCtrl_stcRunPar.u8CloseloopFlag == 0)      // Almost no time in here
    {
		MotorCtrl_stcRunPar.i32Q8_EstimWmHz = Motor_stcPll.i32Q8_EstimWmHz;
		MotorCtrl_stcRunPar.i32Q22_ElecAngle += MotorCtrl_stcRunPar.i32Q22_DeltaThetaTs;
    }

    MotorCtrl_stcRunPar.i32Q22_ElecAngle &= 0x3FFFFF;
    
    ui32_temp = MotorCtrl_stcRunPar.i32Q22_ElecAngle>>12; 
	
    MotorCtrl_stcVdqRef.i32Q12_Sin = Math_Sin(ui32_temp);  
    MotorCtrl_stcVdqRef.i32Q12_Cos = Math_Cos(ui32_temp);
	
    MotorCtrl_stcIdqSensed.i32Q12_Sin = MotorCtrl_stcVdqRef.i32Q12_Sin;
    MotorCtrl_stcIdqSensed.i32Q12_Cos = MotorCtrl_stcVdqRef.i32Q12_Cos;

	#if (0)
    MotorCtrl_stcIdqRef.i32Q12_Sin = MotorCtrl_stcVdqRef.i32Q12_Sin;
    MotorCtrl_stcIdqRef.i32Q12_Cos = MotorCtrl_stcVdqRef.i32Q12_Cos;
	#endif
	
    MotorCtrl_stcEdq.i32Q12_Cos = MotorCtrl_stcVdqRef.i32Q12_Cos;
    MotorCtrl_stcEdq.i32Q12_Sin = MotorCtrl_stcVdqRef.i32Q12_Sin;
}

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_WriteOCCP								  							*
*																			  			*
*   Description: PWM output																	*
*																			  			*				
*   Parameters:   stc_svm_gen_t																*
*				  							  			                               				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

void MotorCtrl_WriteOCCP(stc_svm_gen_t *pstcVal)
{
#if 0
if(Motor_u8RunningDirection == CW)
{
#endif
	PWMU_WriteCompareBuf(pstcVal->i16Aon);
    PWMV_WriteCompareBuf(pstcVal->i16Bon);
    PWMW_WriteCompareBuf(pstcVal->i16Con);
#if 0
}
else
{
	PWMU_WriteCompareBuf(pstcVal->i16Bon);
    PWMV_WriteCompareBuf(pstcVal->i16Aon);
    PWMW_WriteCompareBuf(pstcVal->i16Con);

}
#endif
}

/****************************************************************************************
*																			  			*
*   Function:    Encoder_Start   							  							*
*																			  			*
*   Description: Start encoder and parameters											*
*																			  			*				
*   Parameters:  None																    *
*				  							  			                               	*
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/

void Encoder_Start(void)
{
    encoder.u8_FilterN = Encoder_SpeedFilter_N;         // Get a sample every 2^N samples. 1 means 2 samples, 5 means 32 samples.
    encoder.u8_FilterSamples = 0x01<<(encoder.u8_FilterN);
    encoder.u8_FilterDelta = encoder.u8_FilterSamples*20;//Encoder_SpeedFilter_Delta;
}

/****************************************************************************************
*																			  			*
*   Function:    Encoder_Stop   							  							*
*																			  			*
*   Description: Resets encoder parameters  											*
*																			  			*				
*   Parameters:  None																    *
*				  							  			                               	*
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/

void Encoder_Stop(void)
{
    encoder.i32Q8_SpeedHzfPre = 0;
    encoder.i16_FilterSum = 0;
    encoder.u8_FilterTime = 0;
}

/****************************************************************************************
*																			  			*
*   Function:    Encoder_Read   							  							*
*																			  			*
*   Description: Reads encoder value													*
*																			  			*				
*   Parameters:  None																    *
*				  							  			                               	*
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/

void Encoder_Read(void)
{
    encoder.i16Q10_Theta = ((SPI_ReadRxData())>>9)<<3;
    encoder.i16Q10_Theta = (encoder.i16Q10_Theta + encoder.i16Q10_ThetaOffset)&0x03FF;
    encoder.i32Q22_ThetaElec =  (int32_t)((encoder.i16Q10_Theta)<<12);
    encoder.i32Q22_ThetaElec &= 0x3FFFFF;
    
    if( (encoder.i16Q10_ThetaPre>974) && (encoder.i16Q10_Theta<50) )
        encoder.i16_Revs++;
    if( (encoder.i16Q10_ThetaPre<50) && (encoder.i16Q10_Theta>974) )
        encoder.i16_Revs--;
    
    encoder.i32Q10_ThetaAbs = (encoder.i16_Revs<<10) + encoder.i16Q10_Theta;
    
    if(synchroFlag)
        encoder.i32Q10_ThetaAbs = encoder.i32Q10_ThetaAbs/7;
}

/****************************************************************************************
*																			  			*
*   Function:    Encoder_GetSpeed  							  							*
*																			  			*
*   Description: Calculates encoder speed value											*
*																			  			*				
*   Parameters:  None																    *
*				  							  			                               	*
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/

void Encoder_GetSpeed(void)
{
    int16_t thetacomp, diff, realdiff;
    int32_t speedhz;

    diff = encoder.i16Q10_Theta - encoder.i16Q10_ThetaPre;
    if(diff>512)
        realdiff = 1024-diff;
    else if(diff<(-512))
        realdiff = 1024+diff;
    else 
        realdiff = diff;
    
    encoder.i16_FilterSum += realdiff;
    encoder.i16Q10_ThetaPre = encoder.i16Q10_Theta;
    
    if(encoder.u8_FilterTime == encoder.u8_FilterSamples)
    {
        encoder.u8_FilterTime = 0;
        speedhz = (((encoder.i16_FilterSum)*Motor_u16CarrierFreq/7) >> encoder.u8_FilterN) >> 2;
        encoder.i16_FilterSum = 0;
        
        // Delta filter
        if(speedhz>encoder.i32Q8_SpeedHzf)
            encoder.i32Q8_SpeedHzf += encoder.u8_FilterDelta;
        else if(speedhz<encoder.i32Q8_SpeedHzf)
            encoder.i32Q8_SpeedHzf -= encoder.u8_FilterDelta;
        
        encoder.i32_SpeedRPMf = (encoder.i32Q8_SpeedHzf*60)>>8;
    }
    encoder.u8_FilterTime++;
}


/****************************************************************************************
*																			  			*
*   Function:    Phase_Lock   							  						        *
*																			  			*
*   Description: Phase lock and reset encoder											*
*																			  			*				
*   Parameters:  None																    *
*				  							  			                               	*
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/

void Phase_Lock(void)
{
    // Phase Lock in A

    Motor_Control = CUR_CTRL;
    // Ref current
    MotorCtrl_stcIdqRef.i32Q8_Xd = Q8(1.0);
    MotorCtrl_stcIdqRef.i32Q8_Xq = 0;
    
    // Theta = 0 so the current goes to A
    Motor_stcPll.i32Q22_ElecAngle = 0;
    MotorCtrl_ThetaGen();
    Park(&MotorCtrl_stcIabSensed, &MotorCtrl_stcIdqSensed);
    
    // Check if encoder is not changing
    if(encoder.i32Q10_ThetaAbs == thetaAbsPre)
        synchroCounts++;
    else
        synchroCounts = 0;
    thetaAbsPre = encoder.i32Q10_ThetaAbs;
    
    // Synchronize when enough samples with the same theta
    if(synchroCounts>200)
    {
        encoder.i16Q10_ThetaOffset = 1024 - encoder.i32Q10_ThetaAbs;
        MotorCtrl_stcIdqRef.i32Q8_Xd = 0;
        synchroFlag = 1;
        Motor_Control = CUR_CTRL;
    }

}

/****************************************************************************************
*																			  			*
*   Function:    Reference_Creator  							  						*
*																			  			*
*   Description: Creates reference for loops											*
*																			  			*				
*   Parameters:  None																    *
*				  							  			                               	*
*   Returns:     None														  			*		
*																			  			*		
****************************************************************************************/
/*
void Reference_Generator(void)
{
    int32_t amp, offset, ref, temp;
    
    // Select amplitude and offset
    switch(Motor_Control)
    {
        case SPD_CTRL:
            amp = Motor_i16SpdAmp;
            offset = Motor_i16SpdOffset;
            break;
        
        case CUR_CTRL:
            amp = Motor_i16Q8_IqAmp;
            offset = Motor_i16Q8_IqOffset;
            break;
        
        case POS_CTRL:
            amp = Motor_i32_PosAmp;
            offset = Motor_i32_PosOffset;
            break;
    }
    
    // Select reference mode
    switch(Ref_Mode)
    {
        case REF_SQUARE:
            if(ref_counter<(Ref_Period>>1))
                ref = offset + amp;
            else 
                ref = offset - amp;
            break;
            
        case REF_SINE:
            //temp = (int32_t) ref_counter;
            temp = ref_counter << 10;
            temp = temp/Ref_Period;
            temp = Math_Cos(temp);
            
            ref = ((amp*temp)>>12) + offset;
            break;
            
    }
    
    // Save reference
    switch(Motor_Control)
    {
        case SPD_CTRL:
            MotorCtrl_stcRunPar.i32TargetSpeedRpm = ref;
            break;
        case CUR_CTRL:
            MotorCtrl_stcIdqRef.i32Q8_Xq = ref;
            break;
        case POS_CTRL:
            position_ref = ref;
        break;
    }
    
    // Update counter
    ref_counter++;
    if(ref_counter>Ref_Period)
        ref_counter = 0;
    
}
*/

/****************************************************************************************
*																			  			*
*   Function:    MotorCtrl_Process								  								*
*																			  			*
*   Description: Motor control main flow														*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

void MotorCtrl_Process(void)
{
    /* Update timer */
	MotorCtrl_stcSoftTimer.i32Timer3++;
    Counter++;
    
    /* Protection*/
    MotorCtrl_Protect(); 
    
	if (MotorCtrl_stcRunPar.u8Status == MOTOR_RUNNING)
	{  
        /*Wait for ADC Sample Complete*/
	    while (Adc_stcSample.u8_CompleteFlag != 1);
		Adc_stcSample.u8_CompleteFlag = 0;
        
		/* Read ADC and Get phase current*/
		Adc_MotorCurrentSense();
        
        /* Send reading command to encoder */
        SPI_WriteTxData(0x0000);
        

        /*Clark and Park Transformation*/
		Clark(&MotorCtrl_stcIuvwSensed, &MotorCtrl_stcIabSensed); 
		//Park(&MotorCtrl_stcIabSensed, &MotorCtrl_stcIdqSensed);

		/*Position and Speed Estimate*/
		//MotorPll_PostionEstimate(&Motor_stcPll,&MotorCtrl_stcVabReal,&MotorCtrl_stcIabSensed);   
            
        /* Read encoder */
        while(!SPI_GetRxBufferSize());
        Encoder_Read();
        
        /* Encoder speed calculation */
        Encoder_GetSpeed();
        
        /* Update speed calculation parameters */
            
        /* Use encoder */
    #if 1
        if(synchroFlag)
        {
            //MotorPll_PostionEstimate(&Motor_stcPll,&MotorCtrl_stcVabReal,&MotorCtrl_stcIabSensed);   
            //aux = Motor_stcPll.i32Q22_ElecAngle;
            
            Motor_stcPll.i32Q22_ElecAngle = (encoder.i32Q22_ThetaElec);
            Motor_stcPll.i32Q8_EstimWmHz = encoder.i32Q8_SpeedHzf;
        }
        encoder.i32Q8_SpeedHzfPre = Motor_stcPll.i32Q8_EstimWmHz;
    #else
        MotorPll_PostionEstimate(&Motor_stcPll,&MotorCtrl_stcVabReal,&MotorCtrl_stcIabSensed);   
    #endif
    
    
    
        /* Generate cos and sin and Park */
        MotorCtrl_ThetaGen();
        Park(&MotorCtrl_stcIabSensed, &MotorCtrl_stcIdqSensed);
        

        
			/**Rotor lock protection function*/	
#if 0
			MotorCtrl_stcEab.i32Q8_Xa = Motor_stcPll.i32Q8_Ealpha;
			MotorCtrl_stcEab.i32Q8_Xb = Motor_stcPll.i32Q8_Ebeta;
			Park(&MotorCtrl_stcEab, &MotorCtrl_stcEdq);
			
	   		MotorCtrl_stcRunPar.u32ErroType |= MotorProtect_MotorLock(&Protector_LockPar);
#endif

            // Reference generator
            if( ( (Ref_Mode == REF_SINE) || (Ref_Mode == REF_SQUARE) ) && synchroFlag )
                Reference_Generator();


			MotorCtrl_stcSoftTimer.i32Timer3 &= 0x3;
			if (0 == MotorCtrl_stcSoftTimer.i32Timer3)
			{
                /*Speed Loop*/
                if(Motor_Control == SPD_CTRL)
			        MotorCtrl_SpdReg(); 
			}
			else if (1 == MotorCtrl_stcSoftTimer.i32Timer3)
			{
                /*Field Weaken*/
				#if 0
			   	MotorFw_FieldWeaken(&FieldWeaken_Ctrl,
								   &MotorCtrl_i32VqMax,
								   &MotorCtrl_stcIdqRef.i32Q8_Xd,
								   MotorCtrl_stcRunPar.u8RunningStage); 
                #else
                MotorCtrl_i32VqMax = Q8(5);
				#endif
			}
			else if (2 == MotorCtrl_stcSoftTimer.i32Timer3)
			{
                /*Calculate the Limitation of Current and Voltage*/
				CV_LimitCtrl();
			}	
            
			if(MotorCtrl_stcRunPar.u32ErroType != 0)
			{
				MotorCtrl_Stop();
			}
            
            
            
            /* Phase lock synchronization */
#if 1
            if( (!synchroFlag) )
            {   
                Phase_Lock();
            }
            else
            {
                MotorCtrl_stcIdqRef.i32Q8_Xd = 0;
            }
#endif
            
            // Position loop
            if(Motor_Control == POS_CTRL)
            {
                Pid32(&PosPidCfg, position_ref-encoder.i32Q10_ThetaAbs);
                MotorCtrl_stcIdqRef.i32Q8_Xq = PosPidCfg.i32_Out;
            }
            
      
            // Current loop
            MotorCtrl_stcIqPidReg.i32_OutMax = Q8(5);
            MotorCtrl_stcIqPidReg.i32_OutMin = Q8(-5); 
            //
            
#if 0
            // Old PID function
			Pid_Pos(&MotorCtrl_stcIdPidReg,MotorCtrl_stcIdqRef.i32Q8_Xd-MotorCtrl_stcIdqSensed.i32Q8_Xd);					
			MotorCtrl_stcVdqRef.i32Q8_Xd = MotorCtrl_stcIdPidReg.i32_Out;
            Pid_Pos(&MotorCtrl_stcIqPidReg,MotorCtrl_stcIdqRef.i32Q8_Xq-MotorCtrl_stcIdqSensed.i32Q8_Xq);	   
			MotorCtrl_stcVdqRef.i32Q8_Xq = MotorCtrl_stcIqPidReg.i32_Out;	
#else
            // New 32b PID function with anti wind-up
            Pid32(&IqPidCfg,MotorCtrl_stcIdqRef.i32Q8_Xq-MotorCtrl_stcIdqSensed.i32Q8_Xq);					
			MotorCtrl_stcVdqRef.i32Q8_Xq = IqPidCfg.i32_Out; //iq_out
            Pid32(&IdPidCfg,MotorCtrl_stcIdqRef.i32Q8_Xd-MotorCtrl_stcIdqSensed.i32Q8_Xd);	   
			MotorCtrl_stcVdqRef.i32Q8_Xd = IdPidCfg.i32_Out; //id_out
#endif
    
    /*
            Pid32(&IqPidCfg,MotorCtrl_stcIdqRef.i32Q8_Xq-MotorCtrl_stcIdqSensed.i32Q8_Xq);					
			iq_out = IqPidCfg.i32_Out; //iq_out
            Pid32(&IdPidCfg,MotorCtrl_stcIdqRef.i32Q8_Xd-MotorCtrl_stcIdqSensed.i32Q8_Xd);	   
			id_out = IdPidCfg.i32_Out; //id_out
    */
            
			
#if 0
            /* Voltage Vdq limit */
            MotorCtrl_i32VqMax = Q8(5); //5
            
			if(MotorCtrl_stcVdqRef.i32Q8_Xq > MotorCtrl_i32VqMax)
			{
				MotorCtrl_stcVdqRef.i32Q8_Xq = MotorCtrl_i32VqMax;
			}
            else if(MotorCtrl_stcVdqRef.i32Q8_Xq < -MotorCtrl_i32VqMax)
			{
				MotorCtrl_stcVdqRef.i32Q8_Xq = -MotorCtrl_i32VqMax;
			}
#endif

            /*Calculate Angle*/
			//MotorCtrl_ThetaGen();

            

#if 1
            /* Motor Startup Stage */   // Executes 4 times
			if( (FALSE == MotorCtrl_stcRunPar.u8StartupCompleteFlag) && (synchroFlag) )
			{ 	 
				MotorCtrl_stcRunPar.u8StartupCompleteFlag = MotorStartup(&MotorCtrl_stcStartup); 
				MotorCtrl_stcIdqRef.i32Q8_Xq = (MotorCtrl_stcStartup.i32Q12_Iq)>>4;
			}
#endif

	        /* Inverse Park Transformation*/
			InvPark(&MotorCtrl_stcVdqRef, &MotorCtrl_stcVabRef);
            

        /* SVPWM Calculation*/
		MotorCtrl_stcSvmCalc.i32QN_VaIn = MotorCtrl_stcVabRef.i32Q8_Xa;
		MotorCtrl_stcSvmCalc.i32QN_VbIn = MotorCtrl_stcVabRef.i32Q8_Xb;
		MotorCtrl_stcSvmCalc.i32QN_VdcIn = MotorCtrl_stcRunPar.i32Q8_Vbus;
		            
		Svm_Calc(&MotorCtrl_stcSvmCalc);
		  
		MotorCtrl_stcSvmGen.i16Aon = MotorCtrl_stcSvmCalc.u16Uon;       // These are the values used in PWM
		MotorCtrl_stcSvmGen.i16Bon = MotorCtrl_stcSvmCalc.u16Von;
		MotorCtrl_stcSvmGen.i16Con = MotorCtrl_stcSvmCalc.u16Won;
        
		MotorCtrl_stcVabReal.i32Q8_Xa = MotorCtrl_stcSvmCalc.i32QN_VaReal;
		MotorCtrl_stcVabReal.i32Q8_Xb = MotorCtrl_stcSvmCalc.i32QN_VbReal;

		MotorCtrl_stcSvmGen.i8SectorPre = MotorCtrl_stcSvmGen.i8Sector;
		MotorCtrl_stcSvmGen.i8Sector = MotorCtrl_stcSvmCalc.u16Sector;

#if 1
		if(Adc_stcSample.u8_CompleteFlag == 1)
		{
			Adc_stcSample.u8_CompleteFlag = 0;
		}
#endif
        /* Update PWM Duty*/
		MotorCtrl_WriteOCCP(&MotorCtrl_stcSvmGen);
        
    }  
}

