#include <project.h>
#include "speed_set.h"
#include "motor_ctrl.h"
#include "define.h"
#include "isr.h"
#include "customer_interface.h"


uint8_t Start_Cnt = 0;
uint8_t Protect_Cnt = 0;
/****************************************************************************************
*																			  			*
*   Function:    AD_Speed								  									*
*																			  			*
*   Description: Use AD to set speed															*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                               				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/

void AD_Speed()
{
    int32_t temp, max, min;
    
    if(Ref_Mode == REF_KNOB)
    {
            // Dead Zone check
        if( (MotorCtrl_stcRunPar.i32Q8_VR > ((Motor_i16_VRMax>>1)-Motor_i16_VRDead)) && (MotorCtrl_stcRunPar.i32Q8_VR < ((Motor_i16_VRMax>>1)+Motor_i16_VRDead)) )
            Running = 0;
        else
        {
            Running = 1;
            // Pre calculations
            switch(Motor_Control)
            {
                case SPD_CTRL:
                    max = Motor_i16SpdOffset + Motor_i16SpdAmp;
                    min = Motor_i16SpdOffset - Motor_i16SpdAmp;
                break;
                case CUR_CTRL:
                    max = Motor_i16Q8_IqOffset + Motor_i16Q8_IqAmp;
                    min = Motor_i16Q8_IqOffset - Motor_i16Q8_IqAmp;
                break;
                case POS_CTRL:
                    max = Motor_i32_PosOffset + Motor_i32_PosAmp;
                    min = Motor_i32_PosOffset - Motor_i32_PosAmp;
                break;
            }
            // Calculation
            temp = ( ((max-min)*MotorCtrl_stcRunPar.i32Q8_VR)>>12 ) + min;
            // Assignment
            switch(Motor_Control)
            {
                case SPD_CTRL:
                    MotorCtrl_stcRunPar.i32TargetSpeedRpm = temp;
                break;
                case CUR_CTRL:
                    MotorCtrl_stcIdqRef.i32Q8_Xq = temp;
                break;
                case POS_CTRL:
                    position_ref = temp;
                break;
            }
        }
    
    }
    
}
/****************************************************************************************
*																			  			*
*   Function:    Peripheral_Function								  							*
*																			  			*
*   Description: Running direction and led set													*
*																			  			*				
*   Parameters:   None																		*
*				  							  			                                				*
*   Returns:     None														  				*		
*																			  			*		
****************************************************************************************/
void Peripheral_Function()
{
    static uint8_t Motor_ControlPre = 0;
    ///////////////////// change control typr //////////////
    if((Pin_Dir_Read() == 0)&&(Motor_ControlPre == 1))
	 {
		 Motor_ControlPre = 0;
		 CyDelay(10);
		 if(Pin_Dir_Read() == 0)
		 {
    		if(Running)
    		{
    		    Running = 0;;
    		}
    		else
    		{
    		    Running = 1;
    		}
    		MotorCtrl_Stop();
    		CyDelay(700);
		 }
	 }
	 if(Pin_Dir_Read() == 1)
	 {
		Motor_ControlPre = 1; 
	 }

	//////////////////////Led////////////////////////////
    /* blink LED in 1Hz if error happens */
    if(MotorCtrl_stcRunPar.u32ErroType != 0)
    {
        if(Led_CountTime >= Motor_u16CarrierFreq)
        {
            Led_CountTime = 0;
            Pin_Led_Write(Pin_Led_Read() ^ 0x01);
        }
    }
     //////////////////Clear ErrorType//////////////////
    #if 0   //
     if((MotorCtrl_stcRunPar.u32ErroType != 0)&&(Protect_Cnt < 3)&&(MotorCtrl_stcRunPar.i32TargetSpeedRpm == 0))
     {
        if((MotorCtrl_stcRunPar.i32Q8_VR != 0)&&(MotorCtrl_stcRunPar.i32Q8_VR <= 9))
        {
         Protect_Cnt++;
         MotorCtrl_stcRunPar.u32ErroType = 0;
        }
     }
    #endif
}
/* [] END OF FILE */
